@@ -1,6 +1,6 @@
 package Net::Appliance::Session::Transport;
 {
-  $Net::Appliance::Session::Transport::VERSION = '3.113600';
+  $Net::Appliance::Session::Transport::VERSION = '3.120560';
 }
 
 {
@@ -42,6 +42,10 @@ sub connect {
         $self->$set($options->$slot) if $options->$has;
     }
 
+    if ($self->nci->transport->is_win32 and $self->has_password) {
+        $self->set_password($self->get_password . $self->nci->transport->ors);
+    }
+
     # SSH transport takes a username if we have one
     $self->nci->transport->connect_options->username($self->get_username)
         if $self->has_username
